==> pulin-vue3-common-0.0.17.tgz: package/es/components/MyInputTable/index.js <==
import { createTextVNode as _createTextVNode, createVNode as _createVNode, resolveComponent as _resolveComponent } from "vue";
import { defineComponent } from 'vue';
import { useVModel } from '@vueuse/core';
import './input_key.less';
export var MyInputTable = defineComponent({
  props: {
    header: Array,
    value: Array || undefined,
    hidekey: {
      type: String,
      "default": ''
    },
    onDelete: {
      type: undefined
    }
  },
  emits: ['delete'],
  setup: function setup(props, _ref) {
    var emit = _ref.emit;
    var selected = useVModel(props, 'value', emit);

    var objectKey = function objectKey(i, res) {
      return _createVNode("div", {
        "class": "table_hr_td"
      }, [_createVNode(_resolveComponent("a-input"), {
        'value': res[i],
        "onUpdate:value": function onUpdateValue($event) {
          return res[i] = $event;
        },
        "placeholder": "请输入"
      }, null)]);
    }; // const deleteFun = (idx: number) => {
    //   selected.value?.splice(idx, 1);
    // };


    return function () {
      var _a, _b;

      return _createVNode("div", {
        "class": "input_key_cont"
      }, [_createVNode("div", {
        "class": "table_header"
      }, [(_a = props.header) === null || _a === void 0 ? void 0 : _a.map(function (res) {
        return _createVNode("div", {
          "class": "table_td"
        }, [res.label]);
      })]), _createVNode("div", {
        "class": "table_body"
      }, [(_b = selected.value) === null || _b === void 0 ? void 0 : _b.map(function (res, index) {
        var _a;

        return _createVNode("div", {
          "class": "table_hr"
        }, [(_a = Object.keys(res)) === null || _a === void 0 ? void 0 : _a.map(function (i) {
          var _a;

          if (!(((_a = props.hidekey) === null || _a === void 0 ? void 0 : _a.indexOf(i)) > -1)) {
            return objectKey(i, res);
          }
        }), _createVNode("div", {
          "class": "table_hr_td"
        }, [_createVNode(_resolveComponent("a-button"), {
          "type": "danger",
          "size": "small",
          "onClick": function onClick() {
            emit('delete', index);
          }
        }, {
          "default": function _default() {
            return [_createTextVNode("\u5220\u9664")];
          }
        })])]);
      })])]);
    };
  }
});

==> pulin-vue3-common-0.0.18.tgz: package/es/components/MyInputTable/index.js <==
import { createTextVNode as _createTextVNode, createVNode as _createVNode, resolveComponent as _resolveComponent } from "vue";
import { defineComponent } from 'vue';
import { useVModel } from '@vueuse/core';
import './input_key.less';
export var MyInputTable = defineComponent({
  props: {
    header: Array,
    value: Array || undefined,
    hidekey: {
      type: String,
      "default": ''
    },
    onDelete: {
      type: undefined
    }
  },
  emits: ['delete'],
  setup: function setup(props, _ref) {
    var emit = _ref.emit;
    var selected = useVModel(props, 'value', emit);

    var objectKey = function objectKey(i, res) {
      return _createVNode("div", {
        "class": "table_hr_td"
      }, [_createVNode(_resolveComponent("a-input"), {
        'value': res[i],
        "onUpdate:value": function onUpdateValue($event) {
          return res[i] = $event;
        },
        "placeholder": "请输入"
      }, null)]);
    }; // const deleteFun = (idx: number) => {
    //   selected.value?.splice(idx, 1);
    // };


    return function () {
      var _a, _b;

      return _createVNode("div", {
        "class": "input_key_cont"
      }, [_createVNode("div", {
        "class": "table_header"
      }, [(_a = props.header) === null || _a === void 0 ? void 0 : _a.map(function (res) {
        return _createVNode("div", {
          "class": "table_td"
        }, [res.label]);
      })]), _createVNode("div", {
        "class": "table_body"
      }, [(_b = selected.value) === null || _b === void 0 ? void 0 : _b.map(function (res, index) {
        var _a;

        return _createVNode("div", {
          "class": "table_hr"
        }, [(_a = Object.keys(res)) === null || _a === void 0 ? void 0 : _a.map(function (i) {
          var _a;

          if (!(((_a = props.hidekey) === null || _a === void 0 ? void 0 : _a.indexOf(i)) > -1)) {
            return objectKey(i, res);
          }
        }), _createVNode("div", {
          "class": "table_hr_td"
        }, [_createVNode(_resolveComponent("a-button"), {
          "type": "danger",
          "size": "small",
          "onClick": function onClick() {
            emit('delete', index, res);
          }
        }, {
          "default": function _default() {
            return [_createTextVNode("\u5220\u9664")];
          }
        })])]);
      })])]);
    };
  }
});
